function datestr = convdatefmt(x,src,tgt)
// Convert date format
//
//    Copyright 2015 Trity Technologies.
//    
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 2 of the License, or
//    (at your option) any later version.
//    
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//    
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/
//
// Calling Sequence
//     [datestr,date_no] = thingspeak_convertdate(x,tgt,src)
//
// Parameters
//     x : Date string
//     tgt : Target string format if it is not default ("yyyy.MM.dd.HH.mm.ss")
//     src : Source string format if it is not default ("EEE MMM dd HH:mm:ss z yyyy")
//     datestr : Returned date string in new format 
//     date_no : Returned date number
//
// Description
//    This is to convert the date string to other format
//    
// Examples
// 
// See also
//     thingspeak_fieldvalues
//     thingspeak_newentry
//     thingspeak_plot
//     thingspeak_update
//
// Authors
//     Joshua, Trity Technologies

rhs=argn(2);
iot_init();
// Error Checking
if rhs < 1; error("Expect a least 1 argument."); end 

if rhs == 1   
    oldformat = SimpleDateFormat.new("EEE MMM dd HH:mm:ss z yyyy"); 
    newformat = SimpleDateFormat.new("yyyy.MM.dd.HH.mm.ss");
elseif rhs == 2
    oldformat = SimpleDateFormat.new("EEE MMM dd HH:mm:ss z yyyy"); 
    newformat = SimpleDateFormat.new(tgt);
else
    oldformat = SimpleDateFormat.new(src); 
    newformat = SimpleDateFormat.new(tgt); 
end

xr = size(x,1)
datestr = emptystr(xr,1);

for i = 1:xr
    tempdate = oldformat.parse(x(i));
    datestr(i) = newformat.format(tempdate);
    //datestrsplit = evstr(strsplit(datestr(i),"."));
    //dd = [dd;datestrsplit'];
    //date_no = datenum(datestrsplit');
end
//pause
//date_no = datenum(dd);

endfunction
