function y = get_stock_data(stock_code,start_date,end_date)
// Get the KLSE stock data from Yahoo Finance
//
//    Copyright 2015 Trity Technologies.
//    
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 2 of the License, or
//    (at your option) any later version.
//    
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//    
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/
//
// Calling Sequence
//     y = get_stock_data(stock_code,start_date,end_date)
//
// Parameters
//     stock_code : Stock code for the stock (Yahoo Finance)
//     start_date : Data starting date. String in DDMMYY
//     end_date : Data ending date. String in DDMMYY
//
// Description
//    This is to get the stock date from Yahoo Finanace server
//    
// Examples
//    [mes,cod]=get_stock_code('petronas');
//    start_date = "01011950"; 
//    end_date = "15062015";
//    y = get_stock_data(cod(1),start_date,end_date)
//  
// See also
//     get_stock_code
//
// Authors
//     C.L. Tan, Trity Technologies
//    
main_site_s = 'http://ichart.finance.yahoo.com/';
// stock_code = "7164.KL";
stock_code_s = 'table.csv?s=' + stock_code ;
// start_date = "01121997";
ss = strsplit(start_date)
start_day = strcat(ss(1:2));
start_month = string(strtod(strcat(ss(3:4)))-1);
start_year = strcat(ss(5:8));
start_date_s = '&a=' + start_month + '&b=' + start_day + '&c=' + start_year;
//end_date = "05072015";
ss = strsplit(end_date)
end_day = strcat(ss(1:2));
end_month = string(strtod(strcat(ss(3:4)))-1);
end_year = strcat(ss(5:8));

end_date_s =  '&d=' +  end_month + '&e=' + end_day + '&f=' + end_year;

end_s = '&g=d&ignore=.csv';

url = main_site_s + stock_code_s + start_date_s + end_date_s + end_s;
[fn, contents] = getURL(url);
//[fn, contents] = getURL('http://ichart.finance.yahoo.com/table.csv?s=7164.KL&a=00&b=23&c=2003&d=04&e=15&f=2014&g=d&ignore=.csv');
M1 = csvRead(fn,'', [], 'string');

y = struct();
aa = 'y.' + M1(1,1) + '= (M1($:-1:2,1) )'
execstr(aa);
for cnt = 2:size(M1,2)
    hh = strsubst(M1(1,cnt),' ','');
    aa = 'y.' + hh + '= strtod(M1($:-1:2,cnt) )';
    execstr(aa);
end

    
endfunction
