function p = polyfit(x,y,n)
//POLYFIT Fit polynomial to data.
//   POLYFIT(X,Y,N) finds the coefficients of a polynomial P(X) of
//   degree N that fits the data, P(X(I))~=Y(I), in a least-squares sense.
//
//   For a cubic P(X), the output vector p=[p1 p2 p3 p4] satisfies
//                3        2
//     P(X) = p1 x  + p2 x  + p3 x  + p4 .

if length(x) ~= length(y)
    error('X and Y vectors must be the same size.')
end

x = x(:);
y = y(:);

// Construct Vandermonde matrix.
V = ones(length(x),n+1);
for j = n:-1:1
    V(:,j) = x.*V(:,j+1);
end

// Solve least squares problem.
[Q,R] = qr(V);
QTy = Q'*y;
p = R(1:n+1,1:n+1)\QTy(1:n+1); // Same as p = V\y;
p = p.';          // Polynomial coefficients are row vectors by convention.
p = poly(p($:-1:1),'x','c');

endfunction
