function timestamp = str2ts(timestr,gmt)
// Convert human readable format date to timestamp in milliseconds, with GMT offset
//
//    Copyright 2015 Trity Technologies.
//    
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 2 of the License, or
//    (at your option) any later version.
//    
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//    
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/
//
// Calling Sequence
//    timestamp = str2ts(timestr,gmt)
//
// Parameters
//     timestr : Human readable format in string
//     gmt : GMT offset to get the local time
//     timestamp : Time stamp in unix time milliseconds
//
// Description
//    Convert human readable format date to timestamp in milliseconds, with GMT offset
//
// See also
//    ts2sci 
//    ts2str 
//    ts2vec 
//    vec2ts 
//    sci2ts
//
// Authors
//     C.L. Tan, Trity Technologies    
//               
    rhs=argn(2);
    if rhs < 2; gmt = 8; end    
    
    time_scilab = datenum(strtod(strsplit(timestr,'.'))')
    time_reference = datenum(1970,1,1,gmt,0,0); 
    timestamp = (time_scilab  - time_reference)* 8.64e7;

    

endfunction
