function channel_info= thingspeak_channelinfo(channelID,privacy,apiWriteKey,apiReadKey)
// Get Thingspeak Channel Information
//
//    Copyright 2015 Trity Technologies.
//    
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 2 of the License, or
//    (at your option) any later version.
//    
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//    
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/
//
// Calling Sequence
//     channel_info= thingspeak_channelinfo(channelID,privacy,apiWriteKey,apiReadKey)
//
// Parameters
//     channelID : channel ID in ThingSpeak
//     privacy : Specify whether the channel is 'public' or 'private'
//     apiWriteKey : Write API Key of the channel
//     apiReadKey : Read API Key of the channel. 
//     channel_info : Channel information
//
// Description
//    This is to display the information of the channel in the thingspeak cloud.
//    
// Examples
//    channel = 34896;
//    key = "ACDXWS1NENIBV85Q";
//    channel_info= thingspeak_channelinfo(channel,"private",key,key)
// 
// See also
//     thingspeak_fieldvalues
//     thingspeak_newentry
//     thingspeak_plot
//     thingspeak_update
//
// Authors
//     Joshua, Trity Technologies

    // Create the channel object
    if convstr(privacy) == 'public' then
        channel = jnewInstance(Channel,channelID, apiWriteKey)
    elseif convstr(privacy) == 'private' then
        if apiReadKey == ''
            channel = jnewInstance(Channel,channelID, apiWriteKey,apiWriteKey)
        else
             channel = jnewInstance(Channel,channelID, apiWriteKey,apiReadKey)
        end
    end
    // Obtain the channel feed and extract information from it
    channelfeed = jinvoke(channel,'getChannelFeed')
    channelid = jinvoke(channelfeed,'getChannelId');
    channeldate = jinvoke(channelfeed,'getChannelCreationDate');
    channeldatestr = jinvoke(channeldate,'toString');
    lastupdate = jinvoke(channelfeed,'getChannelUpdateDate');
    lastupdatestr = jinvoke(lastupdate,'toString');
    
    // Place the information inside a structure
    channel_info = struct("channelname",jinvoke(channelfeed,'getChannelName'), ..
                "description",jinvoke(channelfeed,'getChannelDescription'), ..
                "id",double(channelid), ..
                "creationdate",channeldatestr, ..
                "lastupdate",lastupdatestr )                    
    
endfunction
