function time_scilab = ts2sci(timestamp,gmt)
// Convert timestamp in milliseconds to serial date number, with GMT offset
//
//    Copyright 2015 Trity Technologies.
//    
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 2 of the License, or
//    (at your option) any later version.
//    
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//    
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/
//
// Calling Sequence
//    time_scilab = ts2sci(timestamp,gmt)
//
// Parameters
//     timestamp : Time stamp in unix time milliseconds
//     gmt : GMT offset to get the local time
//     time_scilab : Serial date number in Scilab
//
// Description
//    Convert timestamp in milliseconds to serial date number, with GMT offset. 
//
// See also
//    ts2str 
//    ts2vec 
//    vec2ts 
//    sci2ts
//    str2ts
//
// Authors
//     C.L. Tan, Trity Technologies    
//     
    rhs=argn(2);
    if rhs < 2; gmt = 8; end    
    
    time_reference = datenum(1970,1,1,gmt,0,0); 
    time_scilab = time_reference + timestamp / 8.64e7;

    
 
endfunction
