function [timestamp, sen_val, data] = ubidots_get(tokenID,sensorID,num_data)
// Get data to Ubidots sensor's variable
//
//    Copyright 2015 Trity Technologies.
//    
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 2 of the License, or
//    (at your option) any later version.
//    
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//    
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/
//
// Calling Sequence
//    [timestamp, sen_val, data] = ubidots_get(tokenID,sensorID,num_data)
//
// Parameters
//     tokenID : Token ID
//     sensorID : Sensor ID
//     num_data : Numbers of data to get from the sensor's variable, maximum 300
//     timestamp : Time stamp in unix time milliseconds
//     sen_val : Sensor data
//     data : Structure of full details, always not required 
//
// Description
//    Get data to Ubidots sensor's variable. As this function will return all the details for each sensors data, the maximum data could be retrived by this function is 300. To get all data with only timestamp and value, use ubidots_getdata instead.
//
// See also
//    ubidots_getdata
//    ubidots_listsource
//    ubidots_listvar
//    ubidots_post
//
// Authors
//     C.L. Tan, Trity Technologies    
//

    rhs=argn(2);
    if rhs < 2; error('At least 2 inputs required : tokenID,sensorID' ); end  
    if rhs < 3; num_data = 10; end  
    
    if num_data >= 300 then
        num_data = 300;
    end


    str = 'http://things.ubidots.com/api/v1.6/variables/' + sensorID + '/values?page_size=' + string(num_data) + '&token=' + tokenID;
    [temp,message]=getURL(str);
    status = JSONParse(message);
    if  isfield(status,'detail') then
        disp(lasterror);
        error('Data failed to upload to the Ubibots, please check the tokenID and sensorID.');
        data = %nan;
        sen_val = %nan;
        timestamp = %nan;
                
    elseif isfield(status,'count') then
        disp('Total of data found = ' + string(status.count));
        data = status;
        sen_val = list2vec(data.results.value);
        sen_val = sen_val($:-1:1);
        timestamp = list2vec(data.results.timestamp);
        timestamp = timestamp($:-1:1);
        
    else
        disp(lasterror);
        data = %nan;
        sen_val = %nan;
        timestamp = %nan;           
    end
    
endfunction
