function [timestamp, sen_val] = ubidots_getdata(tokenID,sensorID,num_data)
// Get all data to Ubidots sensor's variable
//
//    Copyright 2015 Trity Technologies.
//    
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 2 of the License, or
//    (at your option) any later version.
//    
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//    
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/
//
// Calling Sequence
//    [timestamp, sen_val, data] = ubidots_get(tokenID,sensorID,num_data)
//
// Parameters
//     tokenID : Token ID
//     sensorID : Sensor ID
//     num_data : Numbers of data to get from the sensor's variable
//     timestamp : Time stamp in unix time milliseconds
//     sen_val : Sensor data
//
// Description
//    Get all data to Ubidots sensor's variable. This function will only return the timestamp and sensor value but no other details. To get 300 samples of data with details, use ubidots_get instead.
//
// See also
//    ubidots_get
//    ubidots_listsource
//    ubidots_listvar
//    ubidots_post 
//
// Authors
//     C.L. Tan, Trity Technologies    
//


    rhs=argn(2);
    if rhs < 2; error('At least 2 inputs required : tokenID,sensorID' ); end  
    if rhs < 3; num_data = 10; end  

    // this is only to check the max available data in the varaible 
    str = 'http://things.ubidots.com/api/v1.6/variables/' + sensorID + '/values?page_size=' + '1' + '&token=' + tokenID;
  	[temp,message]=getURL(str);
  	status = JSONParse(message);
    max_num = status.count;

all_data = [];

pg_end = ceil((min(num_data,max_num))/1000);

if pg_end == 0 then
    pg_end = 1;
end

    for pg = 1:pg_end
        if pg == pg_end
            num_to_extract = modulo(num_data,1000);
            if num_to_extract == 0
                num_to_extract = 1000;
            end
            
            
            str = 'http://things.ubidots.com/api/v1.6/variables/' + sensorID + '/values?page_size=' + string(num_to_extract)+ '&page=' + string(pg) + '&token=' + tokenID + '&format=csv';
        else
            str = 'http://things.ubidots.com/api/v1.6/variables/' + sensorID + '/values?page_size=' + '1000' + '&page=' + string(pg) + '&token=' + tokenID + '&format=csv';
        end
        
        [temp,message]=getURL(str);
        temp_data = csvRead(temp);
        all_data = [all_data;temp_data(2:$,2:$)];
    
    end
    timestamp = all_data($:-1:1,1);
    sen_val = all_data($:-1:1,2);
//    status = JSONParse(message);
//    if  isfield(status,'detail') then
//        disp(lasterror);
//        error('Data failed to upload to the Ubibots, please check the tokenID and sensorID.');
//        data = %nan;
//        sen_val = %nan;
//        timestamp = %nan;
//                
//    elseif isfield(status,'count') then
//        disp('Total of data found = ' + string(status.count));
//        data = status;
//        sen_val = list2vec(data.results.value);
//        sen_val = sen_val($:-1:1);
//        timestamp = list2vec(data.results.timestamp);
//        timestamp = timestamp($:-1:1);
//        
//    else
//        disp(lasterror);
//        data = %nan;
//        sen_val = %nan;
//        timestamp = %nan;           
//    end
    
endfunction
